/**
 * Copyright Microsoft Corporation. All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
import { FixturesWithLocation, Location } from './types';
declare type FixtureScope = 'test' | 'worker';
declare type FixtureRegistration = {
    location: Location;
    name: string;
    scope: FixtureScope;
    fn: Function | any;
    auto: boolean;
    deps: string[];
    id: string;
    super?: FixtureRegistration;
};
declare class Fixture {
    runner: FixtureRunner;
    registration: FixtureRegistration;
    usages: Set<Fixture>;
    value: any;
    _teardownFenceCallback: (value?: unknown) => void;
    _tearDownComplete: Promise<void>;
    _setup: boolean;
    _teardown: boolean;
    constructor(runner: FixtureRunner, registration: FixtureRegistration);
    setup(info: any): Promise<void>;
    teardown(): Promise<void>;
}
export declare class FixturePool {
    readonly digest: string;
    readonly registrations: Map<string, FixtureRegistration>;
    constructor(fixturesList: FixturesWithLocation[], parentPool?: FixturePool);
    private validate;
    validateFunction(fn: Function, prefix: string, allowTestFixtures: boolean, location: Location): void;
    resolveDependency(registration: FixtureRegistration, name: string): FixtureRegistration | undefined;
}
export declare class FixtureRunner {
    private testScopeClean;
    pool: FixturePool | undefined;
    instanceForId: Map<string, Fixture>;
    setPool(pool: FixturePool): void;
    teardownScope(scope: string): Promise<void>;
    resolveParametersAndRunHookOrTest(fn: Function, scope: FixtureScope, info: any): Promise<any>;
    setupFixtureForRegistration(registration: FixtureRegistration, info: any): Promise<Fixture>;
}
export declare function inheritFixtureParameterNames(from: Function, to: Function, location: Location): void;
export {};
//# sourceMappingURL=fixtures.d.ts.map