/**
 * Copyright Microsoft Corporation. All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
import * as reporterTypes from './reporter';
import type { TestTypeImpl } from './testType';
import { Location } from './types';
declare class Base {
    title: string;
    file: string;
    line: number;
    column: number;
    parent?: Suite;
    _only: boolean;
    constructor(title: string);
    titlePath(): string[];
}
export declare class Spec extends Base implements reporterTypes.Spec {
    suite: Suite;
    fn: Function;
    tests: Test[];
    _ordinalInFile: number;
    _testType: TestTypeImpl;
    constructor(title: string, fn: Function, ordinalInFile: number, testType: TestTypeImpl);
    ok(): boolean;
    fullTitle(): string;
    _testFullTitle(projectName: string): string;
}
export declare class Suite extends Base implements reporterTypes.Suite {
    suites: Suite[];
    specs: Spec[];
    _fixtureOverrides: any;
    _entries: (Suite | Spec)[];
    _hooks: {
        type: 'beforeEach' | 'afterEach' | 'beforeAll' | 'afterAll';
        fn: Function;
        location: Location;
    }[];
    _addSpec(spec: Spec): void;
    _addSuite(suite: Suite): void;
    findTest(fn: (test: Test) => boolean | void): boolean;
    findSpec(fn: (spec: Spec) => boolean | void): boolean;
    findSuite(fn: (suite: Suite) => boolean | void): boolean;
    totalTestCount(): number;
    _allSpecs(): Spec[];
    _hasOnly(): boolean;
    _buildFixtureOverrides(): any;
}
export declare class Test implements reporterTypes.Test {
    spec: Spec;
    results: reporterTypes.TestResult[];
    skipped: boolean;
    expectedStatus: reporterTypes.TestStatus;
    timeout: number;
    annotations: {
        type: string;
        description?: string;
    }[];
    projectName: string;
    retries: number;
    _id: string;
    _repeatEachIndex: number;
    _projectIndex: number;
    _workerHash: string;
    constructor(spec: Spec);
    status(): 'skipped' | 'expected' | 'unexpected' | 'flaky';
    ok(): boolean;
    fullTitle(): string;
    _appendTestResult(): reporterTypes.TestResult;
}
export {};
//# sourceMappingURL=test.d.ts.map