/**
 * Copyright (c) Microsoft Corporation.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
import type { Location } from './types';
import type { TestError } from './reporter';
export declare class DeadlineRunner<T> {
    private _timer;
    private _done;
    private _fulfill;
    private _reject;
    readonly result: Promise<{
        result?: T;
        timedOut?: boolean;
    }>;
    constructor(promise: Promise<T>, deadline: number | undefined);
    private _finish;
    setDeadline(deadline: number | undefined): void;
}
export declare function raceAgainstDeadline<T>(promise: Promise<T>, deadline: number | undefined): Promise<{
    result?: T;
    timedOut?: boolean;
}>;
export declare function serializeError(error: Error | any): TestError;
export declare function callLocation(fallbackFile?: string): Location;
export declare function errorWithCallLocation(message: string): Error;
export declare function monotonicTime(): number;
export declare function prependErrorMessage(e: Error, message: string): void;
export declare function isRegExp(e: any): e is RegExp;
export declare type Matcher = (value: string) => boolean;
export declare function createMatcher(patterns: string | RegExp | (string | RegExp)[]): Matcher;
export declare function mergeObjects<A extends object, B extends object>(a: A | undefined | void, b: B | undefined | void): A & B;
export declare function wrapInPromise(value: any): Promise<any>;
export declare function formatLocation(location: Location): string;
export declare function forceRegExp(pattern: string): RegExp;
//# sourceMappingURL=util.d.ts.map